/*  getimgsz.c -- Get size and datatype of an LAS image

NAME:
    GETIMGSZ

PURPOSE:
    GETIMGSZ returns the number of bands, lines, and pixels per line,
    and the LAS data-type code, for an LAS image.  It is intended for
    use by TAE TCL procedures which need to know the size and/or
    datatype of an LAS image.

ARGUMENTS:
    IN	    (input)	Name of LAS image for which size information is
			needed.
    NB	   (output)	Number of bands in image.
    NL	   (output)	Number of lines in image.
    NS	   (output)	Number of pixels per image line.
    DT	   (output)	Image data type, as LAS numeric data-type code.

RETURN VALUE:
    The image size values are returned in arguments NB, NL, NS, and DT.

FILE REFERENCES:
    <IN>.ddr is read to determine image size and datatype.

PROGRAM HISTORY:                                  
    01-95	Initial version, R. A. White, PSU/ESSC.

COMPUTER HARDWARE AND/OR SOFTWARE LIMITATIONS:
    This program runs under the TAE/LAS environment.
    It has been tested only under SunOS 4.1.3. and Solaris 2.3. 

PROJECT:
    LAS at PSU/ESSC

INFORMATIONAL AND ERROR MESSAGES:

    These are described in GETIMGSZ.PDF.

ALGORITHM DESCRIPTION:
    Get name of input image and its size and data type
    For each argument to receive output value
	Get name of argument
	Enter value of argument
    Return output values to TAE executive
    									
***************   End of Prolog for GETIMGSZ   ***************	*/
									/*
Header Files:			       					*/

#include	<stdio.h>	/* Standard I/O definitions		*/
#include 	"las.h"		/* Standard LAS include files		*/
#include	"util.h"	/* LAS utility functions		*/
						   			/*
Local Program Constants and Macros:					*/
#define  ABORT \
	   c_errmsg ("Aborting on fatal error", "getimgsz-fatal", &fatal)

									/*
***************   Main Routine for GETIMGSZ   ***************	*/

int main()
    {
	                                              			/*
Local Variable Definitions:						*/

    long	bands[1][MAXBND+1];
				/* List of bands (not checked) */
    struct DDR	ddr;		/* DDR of input image */
    long	dummy[2];	/* Unused values returned by c_getin() */
    long	fatal = -1;	/* Fatal error flag for c_errmsg () */
    char	hname[1][CMLEN];
				/* Input file name */
    long	nb;		/* Number of bands */
    long	one = 1;	/* Constant one */
    long	stdlun;		/* Standard output (not checked) */
    char	tname[1][CMLEN];
				/* CM version of input file name */
    struct PARBLK
		vblock;		/* TAE parameter block */
    long	window[1][4];	/* Input window specifications */
    long	zero = 0;	/* Constant zero */

/*  Get size information  */

    c_inlas (&vblock, &stdlun);
    if (c_getin (&vblock, "IN", &zero, tname, hname, &one, window,
		 bands, &nb, dummy, &one, dummy, &dummy) != E_SUCC)
	ABORT;
    if (c_getddr (hname[0], &ddr) != E_SUCC)
	ABORT;

/*  Enter values into output arguments  */

    q_intg (&vblock, "NB", 1, (TAEINT *) &nb, P_UPDATE);
    q_intg (&vblock, "NL", 1, (TAEINT *) &window[0][2], P_UPDATE);
    q_intg (&vblock, "NS", 1, (TAEINT *) &window[0][3], P_UPDATE);
    q_intg (&vblock, "DT", 1, (TAEINT *) &ddr.dtype, P_UPDATE);

/*  Return output argument values  */

    q_out (&vblock);

    return 0;
    }			/* End of Program GETIMGSZ */
